(***********************************************************************)
(*                                                                     *)
(*                           Caml Light                                *)
(*                                                                     *)
(*            Pierre Weis, projet Cristal, INRIA Rocquencourt          *)
(*                                                                     *)
(*  Copyright 2001 Institut National de Recherche en Informatique et   *)
(*  en Automatique.  Distributed only by permission.                   *)
(*                                                                     *)
(***********************************************************************)

#open "graphics";;
#open "color";;

let draw_pixmap pixmap x y =
 let img = make_image pixmap in
 draw_image img x y;;

let set f px =
 let l = vect_length px in
 if l <> 0 then
 let c = vect_length px.(0) in
 for i = 0 to l - 1 do
  let line = px.(i) in
  for j = 0 to c - 1 do
   line.(j) <- f line.(j)
  done
 done;;

let map f px =
 let l = vect_length px in
 if l = 0 then [||] else
 let c = vect_length px.(0) in
 let res = vect__make_matrix l c 0 in
 for i = 0 to l - 1 do
  let line = px.(i) in
  let res_line = res.(i) in
  for j = 0 to c - 1 do
   res_line.(j) <- f line.(j)
  done
 done;
 res;;

let pixel_is_set ts tb c =
 let h, s, b = hsb_of_color c in
 s >= ts || b >= tb;;

let bitmap_of_pixmap ts tb px =
 let f c = if pixel_is_set ts tb c then white else black in
 map f px;;

(* Set each pixel [p] of an image with the value [f p]. *)

let set_pixmap_pixels = set;;

(* Set to transparent color all the pixels of an image which verifies
   predicate [pred]. *)

let set_pixels_transp pred =
 let f c = if pred c then graphics__transp else c in
 set_pixmap_pixels f;;

(* Set to transparent the pixels of an image which have the background
   color as color. *)

let set_background_transp px =
 let f c = if c = graphics__background then graphics__transp else c in
 set_pixmap_pixels f px;;
